<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Enums\InertiaMethod;

Form::make('email.show')
    ->addFields(function () {
        return [
            Section::make('Details')->fields([
                Display::make('Subject'),
                Display::make('Sender Email')
                    ->name('sender_address'),
                Display::make('Reply-To Email')
                    ->name('reply_to_address'),
            ]),
        ];
    })
    ->addActions(function (EventEmail $email) {

        $totalDelegates = $email->event->delegates->count();
        $receivedDelegates = $email->event->notifications()
            ->where('key', $email->getNotificationKey())
            ->distinct('delegate_id')
            ->count();
        $remainingDelegates = max(0, $totalDelegates - $receivedDelegates);

        $buttons = [
            Button::make("Send to all")
                ->method(InertiaMethod::POST())
                ->route('admin.email.send', [
                    'event' => $email->event->id,
                    'email' => $email->id,
                ]),
        ];

        $content = [
            "Are you sure you want to send the {$email->type->getValue()} email?",
        ];

        if ($receivedDelegates > 0) {
            $content[] = "{$receivedDelegates} delegates have already been sent this email.";

            if ($remainingDelegates > 0) {
                $buttons[] = Button::make("Send to remaining {$remainingDelegates} delegates")
                    ->method(InertiaMethod::POST())
                    ->route('admin.email.send', [
                        'event' => $email->event->id,
                        'email' => $email->id,
                    ]);
            }
        }

        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.index', [
                    'event' => $email->event->id,
                ]),
            Button::make('Edit Email')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.edit', [
                    'event' => $email->event->id,
                    'email' => $email->id,
                ]),
            Button::make('Send Email')
                ->modal([
                    'type' => 'confirm',
                    'content' => $content,
                    'actions' => $buttons,
                ]),
        ];
    });

Form::make('email.edit')
    ->addHandler(new UpdateModel)
    ->addFields(function () {
        return [
            Section::make('Details')->fields([
                Display::make('Type'),
                Text::make('Subject')
                    ->placeholder('You\'re invited!')
                    ->rules([
                        'required',
                    ]),
                Text::make('Sender Email')
                    ->name('sender_address')
                    ->placeholder('info@example.com')
                    ->rules([
                        'required',
                        'email',
                    ]),
                Text::make('Reply-To Email')
                    ->name('reply_to_address')
                    ->placeholder('info@example.com')
                    ->rules([
                        'required',
                        'email',
                    ]),
            ]),
        ];
    })
    ->addActions(function (EventEmail $email) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.index', [
                    'event' => $email->event->id,
                ]),
        ];
    })
    ->addPrimaryAction(function (EventEmail $email) {
        return Button::make('Update Email')
            ->method(InertiaMethod::POST())
            ->route('admin.email.update', [
                'event' => $email->event->id,
                'email' => $email->id,
            ]);
    });
